@@ -22,7 +22,8 @@
   2003/01/20 - NAME_MAX Fix by Hal Pomeranz
   2003/09/01 - BSDI port by Nelson Murilo and Thomas Davidson
   2005/22/05 - APPLE test for limits.h included by Aaron Harwood
-  2007/08/10 - strncpy used instead of strcpy
+  2007/08/10 - strncpy used instead of strcpy - nm
+  2007/12/24 - change `c' variable type - NIDE, Naoyuki
 
 */
 
@@ -238,7 +239,7 @@ int main (int argc, char **argv)
 {
   int norecurse = 0;
   int i, retval;
-  char c;
+  int c;
 
   opterr = 0;
   while ((c = getopt(argc, argv, "n")) > 0) {
