@@ -20,12 +20,11 @@
    Nelson Murilo, nelson@pangeia.com.br
    01/20/01 - More little fixes
    Nelson Murilo, nelson@pangeia.com.br
-   24/01/01 - Segfault in some systems fixed, Thanks for Manfred Bartz
-   02/06/01 - Beter system detection & fix bug in OBSD, Thanks for Rudolf Leitgeb
-   09/19/01 - Another Segfault in some systems fixed, Thanks for Andreas Tirok
-   06/26/02 - Fix problem with maximum uid number - Thanks for Gerard van Wageningen
-   07/02/02 - Minor fixes
-   Nelson Murilo, nelson@pangeia.com.br
+   24/01/01 - Segfault in some systems fixed, Thanks to Manfred Bartz
+   02/06/01 - Beter system detection & fix bug in OBSD, Thanks to Rudolf Leitgeb
+   09/19/01 - Another Segfault in some systems fixed, Thanks to Andreas Tirok
+   06/26/02 - Fix problem with maximum uid number - Thanks to Gerard van Wageningen
+   07/02/02 - Minor fixes - Nelson Murilo, nelson@pangeia.com.br
 */
 
 #if defined(SOLARIS2) || defined(__linux__)
