@@ -44,8 +44,8 @@
   2005/11/15 - Add check for Enye LKM - Nelson Murilo
 
   2005/11/25 - Fix for long lines in PS output - patch by Lantz Moore
-  
-  2006/01/05 - Add getpriority to identify LKMs, ideas from Yjesus(unhide) and 
+
+  2006/01/05 - Add getpriority to identify LKMs, ideas from Yjesus(unhide) and
                Slider/Flimbo (skdet)
 
   2006/01/11 - Fix signal 25 on parisc linux and return of kill() -
@@ -56,7 +56,7 @@
 int main (){ return 0; }
 #else
 #include <stdio.h>
-#include <string.h> 
+#include <string.h>
 #include <errno.h>
 #include <sys/types.h>
 #include <dirent.h>
@@ -64,6 +64,7 @@ int main (){ return 0; }
 #include <stdlib.h>
 #include <unistd.h>
 #include <signal.h>
+#include <sys/stat.h>
 #if defined(__sun)
 #include <procfs.h>
 #include <fcntl.h>
@@ -75,6 +76,8 @@ int main (){ return 0; }
 #define PS_COM 2
 #define PS_LNX 3
 #define PS_MAX 3
+#define ENYELKM "/proc/12345"
+// #define ENYELKM "/tmp/12345"
 
 #if defined(__sun)
 #define FIRST_PROCESS 0
@@ -86,7 +89,7 @@ int main (){ return 0; }
 
 #if !defined (SIGXFSZ)
 #define SIGXFSZ 25
-#endif 
+#endif
 
 static char *ps_cmds[] = {
 	    "ps -edf",
@@ -132,6 +135,7 @@ int main(int argc, char **argv)
    FILE *ps;
    DIR *proc = opendir("/proc");
    struct dirent *dir;
+   struct stat sb;
    int i, j, retps, retdir, pv, verbose;
    long ret = 0L;
    char * tmp_d_name;
@@ -142,7 +146,7 @@ int main(int argc, char **argv)
    psinfo_t psbuf;
 #endif
 
-   pv = verbose = 0; 
+   pv = verbose = 0;
 
    if (!proc)
    {
@@ -161,10 +165,10 @@ int main(int argc, char **argv)
 #if defined(__linux__)
       else if (!memcmp(argv[i], "-p", 2))
       {
-         if (i+1 < argc) 
+         if (i+1 < argc)
             pv = atoi(argv[++i]);
          else
-         { 
+         {
 	    printf("Usage: %s [-v] [-v] [-p procps version]\n", argv[0]);
 	    return 0;
          }
@@ -183,7 +187,7 @@ int main(int argc, char **argv)
 /*  printf("pv = %d\n\r", pv); /* -- DEBUG */
 #endif
 
-/* printf("pscmd = %s\n\r", pscmd); /* -- DEBUG */ 
+/* printf("pscmd = %s\n\r", pscmd); /* -- DEBUG */
    if (!(ps = popen(pscmd, "r")))
    {
        perror("ps");
@@ -335,7 +339,7 @@ int main(int argc, char **argv)
 #endif
       }
 #ifndef __FreeBSD__
-      else 
+      else
       {
          errno = 0;
          getpriority(PRIO_PROCESS, i);
@@ -360,7 +364,7 @@ int main(int argc, char **argv)
       retdir+= errno;
    }
    /* Check for Enye LKM */
-   if (kill (12345, 58) >= 0)
+   if (stat(ENYELKM, &sb) && kill (12345, 58) >= 0)
    {
       printf("Enye LKM found\n");
       retdir+= errno;
